@@ -30,6 +30,13 @@ collections.Callable = collections.abc.Callable
 
 class TestBasics(TestCase):
 
+    def test_read(self):
+        filename = 'files/img/woman1.jpg'
+        img_raw = cv2.imread(filename)
+        self.assertTrue("numpy.ndarray" in str(type(img_raw)))
+        self.assertEqual(img_raw.shape, (640, 960, 3))
+
+    
     def test_write(self):
         # Image path 
         image_path = 'files/img/woman1.jpg'
@@ -48,11 +55,11 @@ class TestBasics(TestCase):
         # Saving the image 
         cv2.imwrite(filename, img) 
         
-        self.assertEqual(len(os.listdir(directory)), 15)
+        self.assertTrue(len(os.listdir(directory)) > 15)
         
         try:
             os.remove(filename)
-            self.assertEqual(len(os.listdir(directory)), 14)
+            self.assertTrue(len(os.listdir(directory)) > 15)
         except OSError as e:  ## if failed, report it back to the user ##
             print ("Error: %s - %s." % (e.filename, e.strerror))
 
